Module: Ratomic::QueueMethods
- Defined in:
- lib/ratomic/queue.rb
Overview
Ruby convenience methods for Queue.
Instance Method Summary collapse
-
#<<(item) ⇒ Ratomic::Queue
Push an item and return the queue for chaining.
Instance Method Details
#<<(item) ⇒ Ratomic::Queue
Push an item and return the queue for chaining.
10 11 12 13 |
# File 'lib/ratomic/queue.rb', line 10 def <<(item) push(item) self end |